@@ -1,10 +1,10 @@
 library(atakrig)
-library(rgdal)
+library(sf)
 
 ## load demo data from rtop package ----
 if (!require("rtop", quietly = TRUE)) message("rtop library is required for demo data.")
 rpath <- system.file("extdata", package="rtop")
-observations <- readOGR(rpath, "observations")
+observations <- read_sf(rpath, "observations")
 
 observations$obs <- observations$QSUMMER_OB/observations$AREASQKM
 
@@ -13,7 +13,7 @@ obs.discrete <- discretizePolygon(observations, cellsize=1500, id="ID", value="o
 pointsv <- deconvPointVgm(obs.discrete, model="Exp", ngroup=12, rd=0.75, fig=TRUE)
 
 ## cross validation ----
-pred.cv <- ataKriging.cv(obs.discrete, nfold=length(observations), pointsv, showProgress = TRUE)
+pred.cv <- ataKriging.cv(obs.discrete, nfold=nrow(observations), pointsv, showProgress = TRUE)
 names(pred.cv)[6] <- "obs"
 
 summary(pred.cv[,c("obs","pred","var")])
@@ -22,6 +22,6 @@ mean(abs(pred.cv$obs - pred.cv$pred))     # MAE
 sqrt(mean((pred.cv$obs - pred.cv$pred)^2))# RMSE
 
 ## prediction ----
-predictionLocations <- readOGR(rpath, "predictionLocations")
+predictionLocations <- read_sf(rpath, "predictionLocations")
 pred.discrete <- discretizePolygon(predictionLocations, cellsize = 1500, id = "ID")
 pred <- ataKriging(obs.discrete, pred.discrete, pointsv$pointVariogram)
